@@ -1,6 +1,6 @@
 package OpenInteract::CommonHandler;
 
-# $Id: CommonHandler.pm,v 1.43 2002/09/16 20:18:36 lachoy Exp $
+# $Id: CommonHandler.pm,v 1.44 2003/11/15 02:02:32 lachoy Exp $
 
 use strict;
 use Data::Dumper    qw( Dumper );
@@ -9,7 +9,7 @@ use SPOPS::Secure   qw( :level );
 require Exporter;
 
 @OpenInteract::CommonHandler::ISA       = qw( OpenInteract::Handler::GenericDispatcher );
-$OpenInteract::CommonHandler::VERSION   = sprintf("%d.%02d", q$Revision: 1.43 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::CommonHandler::VERSION   = sprintf("%d.%02d", q$Revision: 1.44 $ =~ /(\d+)\.(\d+)/);
 @OpenInteract::CommonHandler::EXPORT_OK = qw( OK ERROR );
 
 use constant OK    => '1';
@@ -537,6 +537,8 @@ sub edit {
         return $class->$fail_method({ %{ $p }, error_msg => $error_msg });
     }
 
+    $R->scrib( 1, "Object is new object? ", ( $is_new ) ? 'yes' : 'no' );
+
     # We pass this to the customization routine so you can do
     # comparisons, set off triggers based on changes, etc.
 
@@ -1052,11 +1054,9 @@ sub _remove_post_action_customize { return 1 }
 
 __END__
 
-=pod
-
 =head1 NAME
 
-OpenInteract::CommonHander - Base class that with a few configuration items takes care of many common operations
+OpenInteract::CommonHandler - Base class that with a few configuration items takes care of many common operations
 
 =head1 SYNOPSIS
 
@@ -2111,5 +2111,3 @@ it under the same terms as Perl itself.
 =head1 AUTHORS
 
 Chris Winters <chris@cwinters.com>
-
-=cut
