@@ -1,13 +1,13 @@
 package OpenInteract::Handler::Box;
 
-# $Id: Box.pm,v 1.18 2003/02/17 21:41:11 lachoy Exp $
+# $Id: Box.pm,v 1.20 2003/02/21 12:43:47 lachoy Exp $
 
 use strict;
 use SPOPS::Secure qw( :level );
 use Data::Dumper qw ( Dumper );
 
 @OpenInteract::Handler::Box::ISA     = ();
-$OpenInteract::Handler::Box::VERSION = sprintf("%d.%02d", q$Revision: 1.18 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::Box::VERSION = sprintf("%d.%02d", q$Revision: 1.20 $ =~ /(\d+)\.(\d+)/);
 
 $OpenInteract::Handler::Box::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::Box::default_method    = '';
@@ -58,7 +58,7 @@ sub process_boxes {
         else {
             my $custom_box_method = $BOX_CONFIG->{custom_box_method}
                                     || DEFAULT_METHOD;
-            $R->DEBUG && $R->scrib( "Calling custom box handler:",
+            $R->DEBUG && $R->scrib( 1, "Calling custom box handler:",
                                     "$custom_box_class\->$custom_box_method" );
             eval { $custom_box_class->$custom_box_method() };
             if ( $@ ) {
