@@ -1,26 +1,27 @@
 package OpenInteract::Handler::Classified;
 
-# $Id: Classified.pm,v 1.8 2001/10/14 23:19:33 lachoy Exp $
+# $Id: Classified.pm,v 1.9 2001/11/06 15:03:09 lachoy Exp $
 
 use strict;
+use Class::Date   qw();
 use Data::Dumper  qw( Dumper );
 use OpenInteract::CommonHandler;
 use OpenInteract::Handler::GenericDispatcher qw( DEFAULT_SECURITY_KEY );
 use SPOPS::Secure qw( :level );
 
 @OpenInteract::Handler::Classified::ISA     = qw( OpenInteract::CommonHandler SPOPS::Secure );
-$OpenInteract::Handler::Classified::VERSION = sprintf("%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::Classified::VERSION = sprintf("%d.%02d", q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/);
 
 $OpenInteract::Handler::Classified::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::Classified::default_method    = 'search_form';
 @OpenInteract::Handler::Classified::forbidden_methods = qw();
 %OpenInteract::Handler::Classified::security          = (
  DEFAULT_SECURITY_KEY() => SEC_LEVEL_NONE,
- edit    => SEC_LEVEL_READ,
+ create => SEC_LEVEL_READ, edit => SEC_LEVEL_READ,
  remove  => SEC_LEVEL_WRITE,
 );
 
-use constant DEFAULT_EXPIRE => 60 * 60 * 24 * 7 * 12;     # 12 weeks
+use constant DEFAULT_EXPIRE => '+84D';
 
 sub MY_PACKAGE                 { return 'classified' }
 sub MY_HANDLER_PATH            { return '/Classified' }
@@ -31,6 +32,7 @@ sub MY_SEARCH_FORM_TITLE       { return 'Search for Classified Ads' }
 sub MY_SEARCH_FORM_TEMPLATE    { return 'classified_search_form' }
 sub MY_SEARCH_RESULTS_TITLE    { return 'Classified Search Results' }
 sub MY_SEARCH_RESULTS_TEMPLATE { return 'classified_search_results' }
+sub MY_OBJECT_CREATE_SECURITY  { return SEC_LEVEL_READ }
 sub MY_OBJECT_FORM_TITLE       { return 'Classified Detail' }
 
 sub MY_OBJECT_FORM_TEMPLATE {
@@ -49,6 +51,7 @@ sub MY_EDIT_FIELDS {
 sub MY_EDIT_FIELDS_DATE        { return qw( deadline ) }
 sub MY_ALLOW_SEARCH_FORM       { return 1 }
 sub MY_ALLOW_SEARCH            { return 1 }
+sub MY_ALLOW_CREATE            { return 1 }
 sub MY_ALLOW_SHOW              { return 1 }
 sub MY_ALLOW_EDIT              { return 1 }
 sub MY_ALLOW_REMOVE            { return 1 }
@@ -70,25 +73,14 @@ sub _search_build_where_customize {
         push @{ $value }, "%$keyword%", "%$keyword%";
     }
 
-    my $post_after = $class->_read_field_date( $apr, 'posted_after' );
+    my $post_after = $class->_read_field_date_object( $apr, 'posted_after' );
     if ( $post_after ) {
         push @{ $where }, 'posted_on >= ?';
-        push @{ $value }, $post_after;
+        push @{ $value }, $post_after->strftime( '%Y-%m-%d' );
     }
 }
 
 
-
-# We present dates to the user in three separate fields
-
-sub _read_field_date {
-     my ( $class, $apr, $field ) = @_;
-     return join( '-', $apr->param( $field . '_year' ),
-                       $apr->param( $field . '_month' ),
-                       $apr->param( $field . '_day' ) );
-}
-
-
 # If the user has WRITE access to the object, then he/she is an admin
 # and can set active, expires_on and active_on
 
@@ -118,7 +110,7 @@ sub _edit_customize {
     my $is_admin = 0;
     my $site_admin_id = $R->CONFIG->{default_objects}{site_admin_group};
     foreach my $group ( @{ $R->{auth}{group} } ) {
-       $is_admin++ if ( $group->id == $site_admin_id ); 
+       $is_admin++ if ( $group->id == $site_admin_id );
     }
 
     if ( $is_admin ) {
@@ -126,9 +118,8 @@ sub _edit_customize {
         $classified->{active} = $class->_read_field( $apr, 'active' );
         $classified->{active_on}  ||= $now;
         unless ( $classified->{expires_on} ) {
-            my $expire_time = $R->{time} + DEFAULT_EXPIRE;
-            my @t = localtime( $expire_time );
-            $classified->{expires_on} = join '-', $t[5] + 1900, $t[4] + 1, $t[3];
+            my $expire_date = Class::Date->new( $R->{time} ) + DEFAULT_EXPIRE;
+            $classified->{expires_on} = $expire_date->strftime( '%Y-%m-%d' );;
         }
     }
 }
