@@ -1,15 +1,16 @@
 package OpenInteract::Handler::Group;
 
-# $Id: Group.pm,v 1.8 2002/01/15 17:33:38 lachoy Exp $
+# $Id: Group.pm,v 1.9 2002/04/13 16:42:35 lachoy Exp $
 
 use strict;
+use Data::Dumper  qw( Dumper );
 use OpenInteract::CommonHandler;
 use OpenInteract::Handler::GenericDispatcher qw( DEFAULT_SECURITY_KEY );
 use SPOPS::Secure qw( :level );
-use Data::Dumper  qw( Dumper );
+use SPOPS::Utility;
 
 @OpenInteract::Handler::Group::ISA     = qw(  OpenInteract::CommonHandler SPOPS::Secure );
-$OpenInteract::Handler::Group::VERSION = sprintf("%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::Group::VERSION = sprintf("%d.%02d", q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/);
 
 $OpenInteract::Handler::Group::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::Group::default_method    = 'search';
@@ -120,7 +121,7 @@ sub _post_save {
     my @member_uid   = split ';', $R->apache->param( MEMBER_FIELD );
     $R->DEBUG && $R->scrib( 1, "User IDs retrieved: ", join( '/', @member_uid ) );
 
-    my $member_status = $group->list_process( \@existing_uid, \@member_uid );
+    my $member_status = SPOPS::Utility->list_process( \@existing_uid, \@member_uid );
     $R->DEBUG && $R->scrib( 1, "After processing: ", Dumper( $member_status ) );
 
     my $removed = eval { $group->user_remove( $member_status->{remove} ); };
