@@ -1,6 +1,6 @@
 package OpenInteract::Handler::News;
 
-# $Id: News.pm,v 1.14 2002/09/09 03:06:23 lachoy Exp $
+# $Id: News.pm,v 1.18 2003/01/09 15:07:26 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract::Handler::GenericDispatcher  SPOPS::Secure );
@@ -8,15 +8,19 @@ use SPOPS::Secure qw( :level );
 use Data::Dumper  qw( Dumper );
 use SPOPS::Utility;
 
-$OpenInteract::Handler::News::VERSION = sprintf("%d.%02d", q$Revision: 1.14 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::News::VERSION = sprintf("%d.%02d", q$Revision: 1.18 $ =~ /(\d+)\.(\d+)/);
 
 $OpenInteract::Handler::News::author            = 'chris@cwinters.com';
-$OpenInteract::Handler::News::default_method    = 'listing';
+$OpenInteract::Handler::News::default_method    = 'home';
 @OpenInteract::Handler::News::forbidden_methods = qw( _process_listing );
 %OpenInteract::Handler::News::security          = (
+ home    => SEC_LEVEL_READ,
  latest  => SEC_LEVEL_READ,
- listing => SEC_LEVEL_READ,  show   => SEC_LEVEL_READ, search => SEC_LEVEL_READ,
- edit    => SEC_LEVEL_WRITE, remove => SEC_LEVEL_WRITE,
+ listing => SEC_LEVEL_READ,
+ show    => SEC_LEVEL_READ,
+ search  => SEC_LEVEL_READ,
+ edit    => SEC_LEVEL_WRITE,
+ remove  => SEC_LEVEL_WRITE,
  notify  => SEC_LEVEL_READ,
  show_summary => SEC_LEVEL_WRITE,
  edit_summary => SEC_LEVEL_WRITE,
@@ -25,6 +29,19 @@ $OpenInteract::Handler::News::default_method    = 'listing';
 # 12 weeks -- default expiration for news item
 use constant DEFAULT_EXPIRE => 60 * 60 * 24 * 7 * 12;
 
+sub home {
+    my ( $class, $p ) = @_;
+    my $R = OpenInteract::Request->instance;
+    my %params = ( error_msg  => $p->{error_msg},
+                   status_msg => $p->{status_msg} );
+    $params{section_list} = eval{ $R->news_section->fetch_group({
+                                             order => 'section' }) };
+    return $class->generate_content( $p,
+                                     {},
+                                     \%params,
+                                     { name => 'news::news_home' } );
+}
+
 sub latest {
     my ( $class, $p ) = @_;
     my $R = OpenInteract::Request->instance;
@@ -59,7 +76,15 @@ sub listing {
     my $apr = $R->apache;
     my $option  = $p->{option}  || $apr->param( 'option' );
     my $section = $p->{section} || $apr->param( 'section' );
+    my %date    = ( month => $apr->param( 'news_month' ),
+                    day   => $apr->param( 'news_day' ),
+                    year  => $apr->param( 'news_year' ) );
+    my $use_date = ( $date{month} and $date{year} );
+
     my %cache_params = ( option  => $option, section => $section );
+    if ( $use_date ) {
+        $cache_params{date} = join( '-', map { $date{ $_ } } sort keys %date );
+    }
     my $cached = $class->check_cache( $p, \%cache_params );
     return $cached if ( $cached );
 
@@ -79,8 +104,24 @@ sub listing {
         push @values, $section;
     }
 
-    $params{news_list} = $class->_process_listing({ where => $where,
-                                                    value => \@values,
+    # Feh - I should use a date object for this...
+
+    if ( $use_date ) {
+        $where .= 'AND ( posted_on >= ? AND posted_on < ? )';
+        if ( $date{day} > 0 and $date{day} < 32 ) {
+            push @values, join( '-', $date{year}, $date{month}, $date{day} ),
+                          join( '-', $date{year}, $date{month}, $date{day} + 1 );
+            $params{date} = join( '-', $date{year}, $date{month}, $date{day} );
+        }
+        else {
+            push @values, join( '-', $date{year}, $date{month}, 1 ),
+                          join( '-', $date{year}, $date{month} + 1, 1 );
+            $params{date} = join( '-', $date{year}, $date{month} );
+        }
+    }
+
+    $params{news_list} = $class->_process_listing({ where        => $where,
+                                                    value        => \@values,
                                                     column_group => 'listing' });
     $params{section_list} = eval{ $R->news_section->fetch_group({
                                              order => 'section' }) };
@@ -101,11 +142,11 @@ sub _process_listing {
 
     my $order = $p->{order} || 'posted_on DESC';
     my $news_list = eval { $R->news->fetch_group({
-                                      where  => $p->{where},
-                                      value  => $p->{value},
-                                      limit  => $p->{limit},
+                                      where        => $p->{where},
+                                      value        => $p->{value},
+                                      limit        => $p->{limit},
                                       column_group => $p->{column_group},
-                                      order  => $order  }) };
+                                      order        => $order  }) };
     if ( $@ ) {
         OpenInteract::Error->set( SPOPS::Error->get );
         $R->throw( { code => 403 } );
@@ -152,6 +193,7 @@ sub _process_listing {
     return $news_list;
 }
 
+
 # Display detail of a news item -- displays it in editable form for
 # those who have permission to edit the object.
 
@@ -190,10 +232,10 @@ sub show {
                       : SEC_LEVEL_WRITE;
 
     $params{news}  ||= $R->news->new;
+    $params{section_list} = eval { $R->news_section->fetch_group({
+                                                       order => 'section' }) };
     my ( $tmpl_name );
     if ( $do_edit and $obj_level == SEC_LEVEL_WRITE ) {
-        $params{section_list} = eval { $R->news_section->fetch_group({
-                                                       order => 'section' }) };
         $tmpl_name = 'news_form';
         $R->{page}{title} = ( $params{news}->is_saved )
                               ? "Editing News: $params{news}->{title}"
@@ -235,7 +277,9 @@ sub edit {
 
     # Again, create a new object if one wasn't created before.
     $news ||= $R->news->new;
-    my %no_read = ( posted_by => 1, expires_on => 1, active_on => 1, news_id => 1 );
+
+    my %no_read = map { $_ => 1 }
+                     qw( posted_by expires_on active_on news_id next_id previous_id );
     foreach my $field ( @{ $R->news->field_list } ) {
         next if ( $no_read{ $field } );
         $R->DEBUG && $R->scrib( 1, "Find value for field <<$field>>" );
