@@ -1,13 +1,13 @@
 package OpenInteract::Handler::PageDirectoryIndex;
 
-# $Id: PageDirectoryIndex.pm,v 1.8 2002/01/21 20:33:03 lachoy Exp $
+# $Id: PageDirectoryIndex.pm,v 1.9 2003/04/03 18:26:05 lachoy Exp $
 
 use strict;
 use File::Basename ();
 use SPOPS::Secure qw( :level );
 
 @OpenInteract::Handler::PageDirectoryIndex::ISA     = qw();
-$OpenInteract::Handler::PageDirectoryIndex::VERSION = sprintf("%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::PageDirectoryIndex::VERSION = sprintf("%d.%02d", q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/);
 
 use constant DEFAULT_IMAGE_SOURCE => '/images/icons/unknown.gif';
 use constant DEFAULT_INDEX_FILE   => 'index.html';
@@ -71,7 +71,7 @@ sub simple_index {
         $error_msg = "Cannot read subdirectories from filesystem directory: $!";
     }
     else {
-        @dirs = grep ! /^\./, grep { -d "$fs_dir/$_" } readdir( D );
+        @dirs = sort { $a cmp $b } grep ! /^\./, grep { -d "$fs_dir/$_" } readdir( D );
         closedir( D );
     }
 
