@@ -1,6 +1,6 @@
 package OpenInteract::Handler::Security;
 
-# $Id: Security.pm,v 1.14 2002/04/25 12:35:11 lachoy Exp $
+# $Id: Security.pm,v 1.15 2003/08/12 03:29:24 lachoy Exp $
 
 use strict;
 use Data::Dumper             qw( Dumper );
@@ -9,7 +9,7 @@ use SPOPS::Secure::Hierarchy qw( $ROOT_OBJECT_NAME );
 use OpenInteract::Handler::GenericDispatcher qw( DEFAULT_SECURITY_KEY );
 
 @OpenInteract::Handler::Security::ISA     = qw( OpenInteract::Handler::GenericDispatcher SPOPS::Secure );
-$OpenInteract::Handler::Security::VERSION = sprintf("%d.%02d", q$Revision: 1.14 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::Security::VERSION = sprintf("%d.%02d", q$Revision: 1.15 $ =~ /(\d+)\.(\d+)/);
 
 $OpenInteract::Handler::Security::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::Security::default_method    = 'listing';
@@ -312,7 +312,7 @@ sub _get_user_scopes {
         my $level = $security->{ SEC_SCOPE_USER() }->{ $uid };
         push @s, { scope    => SEC_SCOPE_USER,
                    scope_id => $uid,
-                   name     => $user->{name},
+                   name     => $user->{login_name},
                    level    => $level };
     }
     return @s;
