@@ -1,6 +1,6 @@
 package OpenInteract::Handler::SiteSearch;
 
-# $Id: SiteSearch.pm,v 1.14 2003/02/17 21:41:43 lachoy Exp $
+# $Id: SiteSearch.pm,v 1.15 2003/06/01 18:59:00 lachoy Exp $
 
 use strict;
 use Data::Dumper  qw( Dumper );
@@ -12,7 +12,7 @@ BEGIN {
     };
 }
 @OpenInteract::Handler::SiteSearch::ISA               = qw( OpenInteract::Handler::GenericDispatcher );
-$OpenInteract::Handler::SiteSearch::VERSION           = sprintf("%d.%02d", q$Revision: 1.14 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::SiteSearch::VERSION           = sprintf("%d.%02d", q$Revision: 1.15 $ =~ /(\d+)\.(\d+)/);
 $OpenInteract::Handler::SiteSearch::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::SiteSearch::default_method    = 'search';
 @OpenInteract::Handler::SiteSearch::forbidden_methods = ();
@@ -58,25 +58,37 @@ sub search {
                                       return       => 'raw' }) || [];
         $R->DEBUG && $R->scrib( 2, "List of found object keys and frequencies:",
                                    Dumper( $search_results ) );
+        if ( scalar @{ $search_results } > 0 ) {
 
-        # Persist the raw results and get the ID so we can use them
+            # Persist the raw results and get the ID so we can use them
 
-        my $results = OpenInteract::ResultsManage->new();
-        $params->{search_id} = $results->save( [ map { $_->[0] } @{ $search_results } ],
-                                               { extra      => [ map { $_->[1] } @{ $search_results } ],
-                                                 extra_name => [ 'fulltext_score' ] } );
+            my $results = OpenInteract::ResultsManage->new();
+            $params->{search_id} = eval {
+                $results->save(
+                         [ map { $_->[0] } @{ $search_results } ],
+                         { extra      => [ map { $_->[1] } @{ $search_results } ],
+                           extra_name => [ 'fulltext_score' ] } )
+            };
+        }
     }
 
     # Retrieve the persisted results and pass off to the OpenInteract::FullTextIterator
 
-    my $results = OpenInteract::ResultsManage->new({ search_id => $params->{search_id},
-                                                     min => $min, max => $max });
-    $results->retrieve;
-    $params->{search_iterator} = OpenInteract::FullTextIterator->new({
-                                                  saved_results => $results->{result_list} });
-
-    $params->{total_hits}  = $results->{num_records};
-    $params->{total_pages} = $results->find_total_page_count( $params->{total_hits} );
+    my ( $results );
+    if ( $params->{search_id} ) {
+        $results = OpenInteract::ResultsManage->new(
+                         { search_id => $params->{search_id},
+                           min => $min, max => $max });
+        $results->retrieve;
+        $params->{search_iterator} =
+            OpenInteract::FullTextIterator->new({ saved_results => $results->{result_list} });
+        $params->{total_hits}  = $results->{num_records};
+        $params->{total_pages} = $results->find_total_page_count( $params->{total_hits} );
+    }
+    else {
+        $params->{total_hits} = 0;
+        $params->{total_pages} = 0;
+    }
     $R->{page}->{title} = 'Search Results';
     return $R->template->handler( {}, $params,
                                   { name => 'full_text::search_results' } );
