@@ -1,12 +1,12 @@
 package OpenInteract::Page;
 
-# $Id: Page.pm,v 1.24 2003/04/08 16:49:59 lachoy Exp $
+# $Id: Page.pm,v 1.26 2003/08/13 02:10:08 lachoy Exp $
 
 use strict;
 use Data::Dumper   qw( Dumper );
 use File::Basename qw();
 
-$OpenInteract::Page::VERSION = sprintf("%d.%02d", q$Revision: 1.24 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Page::VERSION = sprintf("%d.%02d", q$Revision: 1.26 $ =~ /(\d+)\.(\d+)/);
 
 use constant DEFAULT_EXTENSION => '.html';
 
@@ -59,13 +59,17 @@ sub page_by_location {
     # Store all potential locations
     my @locations = ();
 
+    my $no_extension = $location !~ /\.\w+$/;
+    my $dir_request  = $location =~ m|/$|;
+
     # First, if this isn't a directory request and we weren't given an
     # extension, check just for that page. Otherwise we get into hinky
     # business with directory indexing in the next step.
 
-    my $no_extension = $location !~ /\.\w+$/;
-    my $dir_request  = $location =~ m|/$|;
-    if ( ! $dir_request and $no_extension ) {
+    # Examples: /foo/bar
+    #           /foo/bar/baz
+
+    if ( $no_extension ) {
         $page = eval { $R->page->fetch( $location ) };
         if ( $@ ) {
             $R->scrib( 0, "Caught error fetching [$location] as page: $@" );
@@ -78,10 +82,15 @@ sub page_by_location {
     # Check to see if this is directory request that corresponds to a
     # page_directory object...
 
-    elsif ( $dir_request or $no_extension ) {
+    # Examples: /foo/bar
+    #           /foo/bar/
+    #           /foo/bar/baz
+    #           /foo/bar/baz/
+
+    if ( $dir_request or $no_extension ) {
         $R->DEBUG && $R->scrib( 1, "Testing [$location] as a directory" );
         my $dir = eval {
-            $R->page_directory->fetch_by_directory( $location, 'yes' )
+            $R->page_directory->fetch_by_directory( $location )
         };
         if ( $@ ) {
             $R->scrib( 0, "Tried to fetch directory but got error: $@" );
@@ -98,20 +107,24 @@ sub page_by_location {
     # not a page requested without an extension; now figure out all
     # the potential locations
 
-    else {
-        push @locations, $location;
-    }
-
     my ( $extension ) = $location =~ /(\.\w+)$/;
     my $default_extension = $class->CONFIG->{default_extension} ||
                             DEFAULT_EXTENSION;
 
+    # Add the default extension to the location without one...
+
     if ( $no_extension ) {
         push @locations, join( '', $location, $default_extension );
         $R->DEBUG && $R->scrib( 1, "Location has no extension; add check ",
                                 "for default extension [$locations[-1]]" ),
     }
+
+    # If it does have an extension, go ahead and add it to the
+    # location list, also adding the same location without an
+    # extension
+
     else {
+        push @locations, $location;
         my ( $sans_extension );
         ( $sans_extension = $location ) =~ s/$extension$//;
         $R->DEBUG && $R->scrib( 1, "Also check location without the extension ",
@@ -123,7 +136,7 @@ sub page_by_location {
     #   (requested) /blah/bloo.shtml
     #   (actual)    /blah/bloo.html
 
-    if ( $extension ne $default_extension ) {
+    if ( $extension and $extension ne $default_extension ) {
         my ( $root, $other_ext ) = $location =~ m|^(.*)(\.\w+)$|;
         $R->DEBUG && $R->scrib( 1, "Extension [$extension] is not the default, also try ",
                                    "[$default_extension]" );
@@ -333,7 +346,9 @@ sub mime_type_content {
     my ( $class, $content ) = @_;
     return undef unless ( $content );
     $class->init_magic;
-    return $MAGIC->checktype_contents( $content );
+    my $mime_type = $MAGIC->checktype_contents( $content );
+    $mime_type =~ s/[\n\r]+$//;
+    return $mime_type;
 }
 
 
