@@ -1,6 +1,6 @@
 package OpenInteract::Page::Database;
 
-# $Id: Database.pm,v 1.6 2002/01/30 17:50:13 lachoy Exp $
+# $Id: Database.pm,v 1.7 2002/12/13 21:41:15 lachoy Exp $
 
 use strict;
 
@@ -43,7 +43,7 @@ sub save {
 # This is a no-op for us, since the location will have been renamed
 # properly in the upgrade
 
-sub rename { return 1 }
+sub rename_content { return 1 }
 
 sub remove {
     my ( $class, $page ) = @_;
