@@ -1,14 +1,13 @@
 package OpenInteract::ResultsManage;
 
-# $Id: ResultsManage.pm,v 1.11 2002/01/02 02:43:56 lachoy Exp $
+# $Id: ResultsManage.pm,v 1.12 2003/04/03 03:22:15 lachoy Exp $
 
 use strict;
 use Data::Dumper  qw( Dumper );
 use IO::File;
 use SPOPS::Utility;
 
-@OpenInteract::ResultsManage::ISA     = ();
-$OpenInteract::ResultsManage::VERSION = sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::ResultsManage::VERSION = sprintf("%d.%02d", q$Revision: 1.12 $ =~ /(\d+)\.(\d+)/);
 
 use constant FILENAME_WIDTH => 20;
 
@@ -161,7 +160,7 @@ sub persist_list {
     my $count = 0;
     foreach my $item ( @{ $to_save } ) {
         my @result_info = ( ref $item )
-                            ? ( ref $item, $item->id )
+                            ? ( ref $item, scalar( $item->id ) )
                             : ( $info{record_class}, $item );
         $result_info[0] = '' if ( $info{record_class} eq $MIXED_IDENTIFIER );
         if ( $info{has_extra} ) {
@@ -185,7 +184,8 @@ sub persist_iterator {
     my %info = ( record_class => undef, num_records => 0 );
     while ( my $item = $to_save->get_next ) {
         $info{record_class} ||= ref $item;
-        $out->print( join( $RECORD_SEP, $info{record_class}, $item->id ), "\n" );
+        $out->print( join( $RECORD_SEP, $info{record_class},
+                                        scalar( $item->id ) ), "\n" );
         $info{num_records}++;
     }
     return \%info;
@@ -563,8 +563,6 @@ sub results_unlock {
 
 __END__
 
-=pod
-
 =head1 NAME
 
 OpenInteract::ResultsManage - Save and retrieve generic search results
@@ -928,6 +926,4 @@ it under the same terms as Perl itself.
 
 =head1 AUTHORS
 
-Chris Winters <chris@cwinters.com>
-
-=cut
+Chris Winters E<lt>chris@cwinters.comE<gt>
