@@ -1,24 +1,31 @@
 package OpenInteract::SQLInstall::User;
 
-# $Id: User.pm,v 1.6 2002/01/02 02:43:56 lachoy Exp $
+# $Id: User.pm,v 1.8 2002/05/02 12:25:35 lachoy Exp $
 
 use strict;
 use vars         qw( %HANDLERS );
+use base         qw( OpenInteract::SQLInstall );
 use Data::Dumper qw( Dumper );
 use SPOPS::Utility;
 
-@OpenInteract::SQLInstall::User::ISA = qw( OpenInteract::SQLInstall );
-
-use constant DEBUG => 0;
-
 my %files = (
-    tables   => [ 'user.sql' ],
-    security => [ 'install_security.dat' ],
+    tables        => [ 'sys_user.sql' ],
+    tables_oracle => [ 'sys_user_oracle.sql', 'sys_user_sequence.sql' ],
+    tables_pg     => [ 'sys_user.sql', 'sys_user_sequence.sql' ],
+    tables_ib     => [ 'sys_user_interbase.sql', 'sys_user_generator.sql' ],
+    security      => [ 'install_security.dat' ],
 );
 
 %HANDLERS = (
     create_structure => { '_default_' => [ 'create_structure',
-                                           { table_file_list => $files{tables} } ] },
+                                           { table_file_list => $files{tables} } ],
+                          'Oracle'    => [ 'create_structure',
+                                           { table_file_list => $files{tables_oracle} } ],
+                          'Pg'        => [ 'create_structure',
+                                           { table_file_list => $files{tables_pg} } ],
+                          'InterBase' => [ 'create_structure',
+                                           { table_file_list => $files{tables_ib} } ],
+    },
     install_data     => { '_default_' => \&create_admin_user },
     install_security => { '_default_' => [ 'install_data',
                                            { data_file_list => $files{security} } ] },
@@ -42,7 +49,7 @@ sub create_admin_user {
                                user_id    => $CONFIG->{default_objects}{superuser} });
     my $password = SPOPS::Utility->generate_random_code( 8 );
     if ( $CONFIG->{login}{crypt_password} ) {
-        $user->{password} = $user->crypt_it( $password );
+        $user->{password} = SPOPS::Utility->crypt_it( $password );
     }
     eval { $user->save({ is_add        => 1,
                          skip_security => 1,
@@ -52,7 +59,7 @@ sub create_admin_user {
         my $ei = SPOPS::Error->get;
         $status->{ok}  = 0;
         $status->{msg} = "Cannot create admin user!\nError: $@\nVerbose: $ei->{system_msg}";
-        DEBUG && warn "Cannot create admin user! Error: ", Dumper( $ei ), "\n";
+        $R->DEBUG && warn "Cannot create admin user! Error: ", Dumper( $ei ), "\n";
     }
     else {
         my $achtung     = '**WRITE THIS PASSWORD DOWN!**';
