@@ -1,6 +1,6 @@
 package OpenInteract::SiteTemplate;
 
-# $Id: SiteTemplate.pm,v 1.9 2002/08/25 17:04:36 lachoy Exp $
+# $Id: SiteTemplate.pm,v 1.10 2002/11/24 19:38:29 lachoy Exp $
 
 use strict;
 use base qw( Exporter Class::Accessor );
@@ -8,7 +8,7 @@ use File::Basename   qw();
 use File::Path       qw();
 use File::Spec       qw();
 
-$OpenInteract::SiteTemplate::VERSION = substr(q$Revision: 1.9 $, 10);
+$OpenInteract::SiteTemplate::VERSION = substr(q$Revision: 1.10 $, 10);
 
 my $NAME_SEPARATOR = '::';
 sub NAME_SEPARATOR { return $NAME_SEPARATOR }
@@ -143,14 +143,14 @@ sub _find_in_global {
 # package template directory. Return undef if not found.
 
 sub _find_in_package {
-    my ( $class, $package, $name ) = @_;
+    my ( $class, $package_name, $file_name ) = @_;
     my $R = OpenInteract::Request->instance;
     my $website_dir = $R->CONFIG->get_dir( 'base' );
     my $repository  = $R->repository->fetch(
                                        undef, { directory => $website_dir } );
-    my $package = $repository->fetch_package_by_name({ name => $package });
+    my $package = $repository->fetch_package_by_name({ name => $package_name });
     my $template_dir = File::Spec->catfile( $website_dir, $package->{package_dir}, 'template' );
-    return $class->_find_template_in_directory( $template_dir, $name );
+    return $class->_find_template_in_directory( $template_dir, $file_name );
 }
 
 # Finds a template file in a particular directory -- cycles through
