@@ -1,11 +1,11 @@
 package OpenInteract::User;
 
-# $Id: User.pm,v 1.9 2002/01/02 02:43:55 lachoy Exp $
+# $Id: User.pm,v 1.11 2002/01/28 13:02:27 lachoy Exp $
 
 use strict;
 use SPOPS::Secure qw( :level :scope );
 
-$OpenInteract::User::VERSION = sprintf("%d.%02d", q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::User::VERSION = sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/);
 $OpenInteract::User::crypt_password = undef;
 
 
@@ -18,6 +18,25 @@ sub _class_initialize {
 }
 
 
+########################################
+# CLASS METHODS
+
+sub fetch_by_login_name {
+    my ( $class, $login_name, $p ) = @_;
+    $p ||= {};
+    my $oper = $class->sql_case_insensitive;
+    my $user_list = $class->fetch_group({ where => "login_name $oper ?",
+                                          value => [ $login_name ],
+                                          %{ $p } });
+    if ( $p->{return_single} ) {
+        return $user_list->[0];
+    }
+    return $user_list;
+}
+
+
+########################################
+# OBJECT METHODS
 
 sub make_public {
     my ( $self ) = @_;
@@ -92,8 +111,10 @@ sub is_in_group {
     my $R = OpenInteract::Request->instance;
     my $check_group_id = ( ref $group_spec )
                            ? $group_spec->id : $group_spec;
+    my $type = $R->CONFIG->{id}{group_type};
     foreach my $group ( @{ $R->{auth}{group} } ) {
-        return 1 if ( $group->id == $check_group_id );
+        return 1 if ( $type eq 'int' and $group->id == $check_group_id );
+        return 1 if ( $type eq 'char' and $group->id eq $check_group_id );
     }
     return undef;
 }
@@ -129,6 +150,18 @@ Basic methods for user objects
 
 =head1 METHODS
 
+=head2 Class Methods
+
+B<fetch_by_login_name( $login_name, [ \%params ] )>
+
+Retrieve a single user by C<$login_name>. This performs a
+case-insensitive search (if available). Pass a true value for
+'return_single' in C<\%params> to return a single object, and pass a
+true value for 'skip_security' in C<\%params> to skip security
+checks. (Useful when finding a user to login with.)
+
+=head2 Object Methods
+
 B<full_name()>
 
 Returns the full name -- it is accessed often enough that we just made
@@ -153,8 +186,12 @@ Returns true if the user is in the group, false, if not.
 
 =head1 TO DO
 
+Nothing known.
+
 =head1 BUGS
 
+None known.
+
 =head1 COPYRIGHT
 
 Copyright (c) 2001-2002 intes.net, inc.. All rights reserved.
