@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-# $Id: add_objects_to_index.pl,v 1.4 2001/07/12 18:00:38 lachoy Exp $
+# $Id: add_objects_to_index.pl,v 1.5 2002/11/10 15:47:56 lachoy Exp $
 
 # add_objects_to_index.pl -- Re-index a particular class.
 
@@ -42,15 +42,18 @@ use OpenInteract::Startup;
             "'fulltext_field' key in your object configuration.\n";
     }
 
-    # Retrieve all the objects -- but define a column group on the fly
-    # for just the fields we need (sneaky)
+    # Retrieve all the objects -- but if the 'fulltext' column group
+    # is defined use it.
 
-    $CONFIG->{column_group}->{fulltext} ||= $ft_fields;
+    my ( $column_group );
+    if ( $CONFIG->{column_group}{fulltext} ) {
+        $column_group = 'fulltext';
+    }
 
     my $iter = eval { $obj_class->fetch_iterator({ 
                                      skip_security => 1,
                                      where         => $OPT_where,
-                                     column_group  => 'fulltext' }) };
+                                     column_group  => $column_group }) };
     if ( $@ ) {
         my $ei = SPOPS::Error->get;
         die "Fetch of objects failed!\n",
