@@ -1,16 +1,12 @@
 #!/usr/bin/perl -w
 
-# $Id: scan_for_new.pl,v 1.6 2002/01/16 23:24:29 lachoy Exp $
+# $Id: scan_for_new.pl,v 1.7 2002/01/23 22:01:40 lachoy Exp $
 
 use strict;
 use Data::Dumper qw( Dumper );
 use File::Find;
 use OpenInteract::Startup;
 
-use lib qw( .. );
-use OpenInteract::PageScan;
-
-
 use constant DEBUG => 0;
 
 my ( @OPT_skip );
@@ -26,9 +22,11 @@ my ( $OPT_root, $OPT_debug, $OPT_active_days );
                                         '', \%opts, { temp_lib => 'lazy' } );
 
     $OPT_debug ||= DEBUG;
+    $R->CONFIG->{DEBUG} = $OPT_debug;
+
+    require OpenInteract::PageScan;
 
     push @OPT_skip, OpenInteract::PageScan->default_skip;
-
     my $scanner = OpenInteract::PageScan->new({ file_skip  => \@OPT_skip,
                                                 file_root  => $OPT_root,
                                                 expires_in => $OPT_active_days,
