@@ -1,6 +1,6 @@
 CREATE TABLE classified (
  classified_id %%INCREMENT%%,
- posted_on     datetime not null, 
+ posted_on     timestamp not null, 
  posted_by     %%USERID_TYPE%% not null,
  title         varchar(50),
  organization  varchar(75),
@@ -16,7 +16,7 @@ CREATE TABLE classified (
  email         varchar(75),
  url           varchar(75),
  active        char(3) default 'yes',
- expires_on    datetime,
- active_on     datetime,
+ expires_on    timestamp,
+ active_on     timestamp,
  primary key   ( classified_id )
 )
\ No newline at end of file
