@@ -1,6 +1,6 @@
 CREATE TABLE full_text_index (
+ object_key    char(32) not null,
  term          varchar(30) not null,
- ft_oid        varchar(125) not null,
  occur         int not null,
- primary key   ( term, ft_oid )
+ primary key   ( term, object_key )
 )
\ No newline at end of file
