@@ -9,6 +9,8 @@ CREATE TABLE news (
  image_align   varchar2(5) null,
  section       varchar2(20) default 'Public',
  active        char(3) default 'yes',
+ previous_id   int null,
+ next_id       int null,
  expires_on    date null,
  active_on     date null,
  primary key   ( news_id )
